@@ -106,6 +106,7 @@ static void pe_stat_record(pe_stat *st, double elapse);
 #define PE_RUNNING	0x08  /* virtual flag */
 #define PE_REENTRANT	0x10
 #define PE_HARD		0x20
+#define PE_PERLCB	0x40
 
 #define PE_VISIBLE_FLAGS \
 (PE_ACTIVE | PE_SUSPEND | PE_QUEUED | PE_RUNNING)
@@ -134,6 +135,10 @@ static void pe_stat_record(pe_stat *st, double elapse);
 #define EvHARD_on(ev)		(EvFLAGS(ev) |= PE_HARD)   /* :-) */
 #define EvHARD_off(ev)		(EvFLAGS(ev) &= ~PE_HARD)
 
+#define EvPERLCB(ev)		(EvFLAGS(ev) & PE_PERLCB)
+#define EvPERLCB_on(ev)		(EvFLAGS(ev) |= PE_PERLCB)
+#define EvPERLCB_off(ev)	(EvFLAGS(ev) &= ~PE_PERLCB)
+
 #define EvCANDESTROY(ev)					\
  (ev->refcnt == 0 && ev->running == 0 &&			\
   !(EvFLAGS(ev)&(PE_ACTIVE|PE_SUSPEND|PE_QUEUED)))
